# 基础组件

# 发布历史

```
0.0.1 初始版，测试发布功能
0.0.2
0.0.3.230817
0.0.6
    增加两个方法 find_files getWorkDirectory
0.0.7
    debug
0.0.8
    新增 TaskManage,Executing
0.0.9   正式 2024-09-10 降薪30%
    调整debug 输出格式
0.0.10 发布
    增加  read_stream, write_stream
    增加  limitThreadPoolExecutor
0.0.11
    新增 source.py 模块, Singleton
0.0.12
    win 模块
    gps dsm
0.0.13
    单例模式 装饰器
    增加  compile_source 方法
    增加类 EventLoop
0.0.14
    log 增加方法 create_logger
0.0.15
    util.__init__.py 优化

```

# 安装

pip install co6co==0.0.2
